@@ -1,6 +1,6 @@
 /* The relp client.
  *
- * Copyright 2008-2013 by Rainer Gerhards and Adiscon GmbH.
+ * Copyright 2008-2018 by Rainer Gerhards and Adiscon GmbH.
  *
  * This file is part of librelp.
  *
@@ -265,6 +265,8 @@ relpCltSetAuthMode(relpClt_t *pThis, char *mode)
 		pThis->authmode = eRelpAuthMode_Fingerprint;
 	else if(!strcasecmp(mode, "name"))
 		pThis->authmode = eRelpAuthMode_Name;
+	else if(!strcasecmp(mode, "certvalid"))
+		pThis->authmode = eRelpAuthMode_CertValid;
 	else
 		ABORT_FINALIZE(RELP_RET_INVLD_AUTH_MD);
 
