@@ -1,6 +1,6 @@
 #!/bin/bash
 . ${srcdir}/test-framework.sh
-startup_receiver -T
+startup_receiver -T -e error.out.log
 
 echo 'Send Message...'
 ./send -t 127.0.0.1 -p $TESTPORT -m "testmessage" -T $OPT_VERBOSE 1>>librelp.out.log 2>&1
