@@ -6,5 +6,5 @@ echo 'Start Receiver...'
 # NOT USING startup_receiver!
 ./receive -p $TESTPORT -T -a "name" -y ${srcdir}/tls-certs/cert.pem -z ${srcdir}/tls-certs/key.pem -P "rsyslog" > librelp.out.log
 
-check_output "receive: parameter missing; certificates and permittedPeer required"
+check_output "receive:.*parameter missing; certificates and permittedPeer required"
 terminate
